﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing;

using MindFusion.Charting;
using MindFusion.Charting.Components;
using MindFusion.Drawing;

using Color = System.Drawing.Color;
using Brush = MindFusion.Drawing.Brush;
using SolidBrush = MindFusion.Drawing.SolidBrush;

namespace TowerChart
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			var leftSeries = new EventSeries(
				new List<ChartEvent>
				{
					new ChartEvent(0, 1, 3) { InnerLabel = "22'45\"", OuterLabel = "Fernandes" },
					new ChartEvent(2, 1, 2) { InnerLabel = "59'27\"", OuterLabel = "Sanchez" }
				});
			leftSeries.Title = "Spain";
			towerChart.LeftSeries = leftSeries;

			var rightSeries = new EventSeries(
				new List<ChartEvent>
				{
					new ChartEvent(1, 1, 2) { InnerLabel = "38'27\"", OuterLabel = "Chiesa" }
				});
			rightSeries.Title = "Italy";
			towerChart.RightSeries = rightSeries;

			var brushes = new List<Brush>()
			{
				 new SolidBrush(ColorTranslator.FromHtml("#669acc")),
				 new SolidBrush(ColorTranslator.FromHtml("#616a7f"))
			};

			var strokes = new List<Brush>(){
				new SolidBrush(ColorTranslator.FromHtml("#FFFFFF"))};

			towerChart.Plot.SeriesStyle = new PerSeriesStyle(
				brushes, strokes, null, null);

			towerChart.Theme.DataLabelsFontSize = 12;
			towerChart.Theme.HighlightStroke = new SolidBrush(
				ColorTranslator.FromHtml("#ce0000"));

			towerChart.LegendRenderer.Background = new SolidBrush(
				ColorTranslator.FromHtml("#e0e9e9"));
			towerChart.LegendRenderer.BorderStroke = new SolidBrush(
				ColorTranslator.FromHtml("#c0c0c0"));
			towerChart.LegendRenderer.ShowSeriesElements = false;
			towerChart.LegendRenderer.TitleFontSize = 14.0;

			towerChart.BackColor = Color.White;
			towerChart.Margins = new Margins(250, 20, 250, 20);

			layoutCombo.SelectedIndex = 0;
			shapeCombo.SelectedIndex = 0;
		}

		void chbShowLegend_CheckedChanged(object sender, EventArgs e)
		{
			towerChart.ShowLegend = !towerChart.ShowLegend;
			towerChart.Invalidate();
		}

		void chbShowDataLabels_CheckedChanged(object sender, EventArgs e)
		{
			if (chbShowDataLabels.Checked)
				towerChart.ShowDataLabels = LabelKinds.All;
			else
				towerChart.ShowDataLabels = LabelKinds.None;
			towerChart.Invalidate();
		}

		private void tbMargins_Scroll(object sender, EventArgs e)
		{
			towerChart.Margins = new Margins(
				tbMargins.Value, 20, tbMargins.Value, 20);
		}

		private void tbPadding_Scroll(object sender, EventArgs e)
		{
			towerChart.SeriesPadding = tbPadding.Value;
		}

		private void layoutCombo_SelectedIndexChanged(object sender, EventArgs e)
		{
			towerChart.TowerLayout = (TowerLayout)layoutCombo.SelectedIndex;
		}

		private void shapeCombo_SelectedIndexChanged(object sender, EventArgs e)
		{
			towerChart.SegmentShape = (TowerSegmentShape)shapeCombo.SelectedIndex;
		}

		private void addLeftBtn_Click(object sender, EventArgs e)
		{
			var series = (EventSeries)towerChart.LeftSeries;
			series.Values.Add(
				new ChartEvent(counter++, 1, DateTime.Now.Ticks % 2 + 2)
				{
					InnerLabel = DateTime.Now.Second.ToString(),
					OuterLabel = "Player " + (DateTime.Now.Ticks % 12).ToString()
				}); ;
			towerChart.Invalidate();

			if (towerChart.Range.Value < counter)
				towerChart.Range = counter;
		}

		private void addRightBtn_Click(object sender, EventArgs e)
		{
			var series = (EventSeries)towerChart.RightSeries;
			series.Values.Add(
				new ChartEvent(counter++, 1, DateTime.Now.Ticks % 2 + 2)
				{
					InnerLabel = DateTime.Now.Second.ToString(),
					OuterLabel = "Player " + (DateTime.Now.Ticks % 12).ToString()
				}); ;
			towerChart.Invalidate();

			if (towerChart.Range.Value < counter)
				towerChart.Range = counter;
		}

		int counter = 3;
	}
}
